@@ -9,6 +9,7 @@ import enum
 import functools
 import inspect
 import itertools
+import os
 import typing
 import warnings
 from typing import (
@@ -162,7 +163,7 @@ class UnsupportedNestedTypeMessage:
     message: str
 
 
-def is_nested_type(typ: TypeForm[Any], default_instance: _DefaultInstance) -> bool:
+def is_nested_type(typ: TypeForm[Any], default_instance: DefaultInstance) -> bool:
     """Determine whether a type should be treated as a 'nested type', where a single
     type can be broken down into multiple fields (eg for nested dataclasses or
     classes).
@@ -177,7 +178,7 @@ def is_nested_type(typ: TypeForm[Any], default_instance: _DefaultInstance) -> bo
 
 def field_list_from_callable(
     f: Union[Callable, TypeForm[Any]],
-    default_instance: _DefaultInstance,
+    default_instance: DefaultInstance,
 ) -> Tuple[
     Union[Callable, TypeForm[Any]], Dict[TypeVar, TypeForm], List[FieldDefinition]
 ]:
@@ -221,7 +222,7 @@ def field_list_from_callable(
 # Implementation details below.
 
 
-_DefaultInstance = Union[
+DefaultInstance = Union[
     Any, PropagatingMissingType, NonpropagatingMissingType, ExcludeFromCallType
 ]
 
@@ -240,7 +241,7 @@ _known_parsable_types = set(
 
 def _try_field_list_from_callable(
     f: Union[Callable, TypeForm[Any]],
-    default_instance: _DefaultInstance,
+    default_instance: DefaultInstance,
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     f, found_subcommand_configs = _resolver.unwrap_annotated(
         f, conf._confstruct._SubcommandConfiguration
@@ -249,7 +250,7 @@ def _try_field_list_from_callable(
         default_instance = found_subcommand_configs[0].default
 
     # Unwrap generics.
-    f, type_from_typevar = _resolver.resolve_generic_types(f)
+    f, _ = _resolver.resolve_generic_types(f)
     f = _resolver.narrow_type(f, default_instance)
     f_origin = _resolver.unwrap_origin_strip_extras(cast(TypeForm, f))
 
@@ -257,9 +258,17 @@ def _try_field_list_from_callable(
     #     1. Set cls to the type.
     #     2. Consider `f` to be `cls.__init__`.
     cls: Optional[TypeForm[Any]] = None
-    if isinstance(f, type):
+    if inspect.isclass(f):
         cls = f
-        f = cls.__init__  # type: ignore
+        if hasattr(cls, "__init__") and cls.__init__ is not object.__init__:
+            f = cls.__init__  # type: ignore
+        elif hasattr(cls, "__new__") and cls.__new__ is not object.__new__:
+            f = cls.__new__
+        else:
+            return UnsupportedNestedTypeMessage(
+                f"Cannot instantiate class {cls} with no unique __init__ or __new__"
+                " method."
+            )
         f_origin = cls  # type: ignore
 
     # Try field generation from class inputs.
@@ -299,12 +308,20 @@ def _try_field_list_from_callable(
         cls is not None and cls in _known_parsable_types
     ) or _resolver.unwrap_origin_strip_extras(f) in _known_parsable_types:
         return UnsupportedNestedTypeMessage(f"{f} should be parsed directly!")
+    elif (
+        cls is not None
+        and issubclass(cls, os.PathLike)
+        and _instantiators.is_type_string_converter(cls)
+    ):
+        return UnsupportedNestedTypeMessage(
+            f"PathLike {cls} should be parsed directly!"
+        )
     else:
         return _try_field_list_from_general_callable(f, cls, default_instance)
 
 
 def _field_list_from_typeddict(
-    cls: TypeForm[Any], default_instance: _DefaultInstance
+    cls: TypeForm[Any], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     field_list = []
     valid_default_instance = (
@@ -336,7 +353,7 @@ def _field_list_from_typeddict(
 
 
 def _field_list_from_namedtuple(
-    cls: TypeForm[Any], default_instance: _DefaultInstance
+    cls: TypeForm[Any], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     # Handle NamedTuples.
     #
@@ -367,11 +384,25 @@ def _field_list_from_namedtuple(
 
 
 def _field_list_from_dataclass(
-    cls: TypeForm[Any], default_instance: _DefaultInstance
+    cls: TypeForm[Any], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
+    # Check if dataclass is a flax module.
+    is_flax_module = False
+    try:
+        import flax
+
+        if issubclass(cls, flax.linen.Module):
+            is_flax_module = True
+    except ImportError:
+        pass
+
     # Handle dataclasses.
     field_list = []
     for dc_field in filter(lambda field: field.init, _resolver.resolved_fields(cls)):
+        # For flax modules, we ignore the built-in "name" and "parent" fields.
+        if is_flax_module and dc_field.name in ("name", "parent"):
+            continue
+
         default = _get_dataclass_field_default(dc_field, default_instance)
 
         # Try to get helptext from field metadata. This is also intended to be
@@ -408,7 +439,7 @@ def _is_pydantic(cls: TypeForm[Any]) -> bool:
 
 
 def _field_list_from_pydantic(
-    cls: TypeForm[Any], default_instance: _DefaultInstance
+    cls: TypeForm[Any], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     assert pydantic is not None
 
@@ -423,9 +454,9 @@ def _field_list_from_pydantic(
             FieldDefinition.make(
                 name=pd_field.name,
                 typ=pd_field.outer_type_,
-                default=MISSING_NONPROP
-                if pd_field.required
-                else pd_field.get_default(),
+                default=(
+                    MISSING_NONPROP if pd_field.required else pd_field.get_default()
+                ),
                 helptext=helptext,
             )
         )
@@ -443,7 +474,7 @@ def _is_attrs(cls: TypeForm[Any]) -> bool:
 
 
 def _field_list_from_attrs(
-    cls: TypeForm[Any], default_instance: _DefaultInstance
+    cls: TypeForm[Any], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     assert attr is not None
 
@@ -470,7 +501,7 @@ def _field_list_from_attrs(
 
 
 def _field_list_from_tuple(
-    f: Union[Callable, TypeForm[Any]], default_instance: _DefaultInstance
+    f: Union[Callable, TypeForm[Any]], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     # Fixed-length tuples.
     field_list = []
@@ -530,7 +561,7 @@ def _field_list_from_tuple(
 
 
 def _field_list_from_sequence_checked(
-    f: Union[Callable, TypeForm[Any]], default_instance: _DefaultInstance
+    f: Union[Callable, TypeForm[Any]], default_instance: DefaultInstance
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     contained_type: Any
     if len(get_args(f)) == 0:
@@ -548,7 +579,7 @@ def _field_list_from_sequence_checked(
 
 def _try_field_list_from_sequence_inner(
     contained_type: TypeForm[Any],
-    default_instance: _DefaultInstance,
+    default_instance: DefaultInstance,
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     # When no default instance is specified:
     #     If we have List[int] => this can be parsed as a single field.
@@ -592,7 +623,7 @@ def _try_field_list_from_sequence_inner(
 
 def _field_list_from_dict(
     f: Union[Callable, TypeForm[Any]],
-    default_instance: _DefaultInstance,
+    default_instance: DefaultInstance,
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     if default_instance in MISSING_SINGLETONS:
         return UnsupportedNestedTypeMessage(
@@ -616,7 +647,7 @@ def _field_list_from_dict(
 def _try_field_list_from_general_callable(
     f: Union[Callable, TypeForm[Any]],
     cls: Optional[TypeForm[Any]],
-    default_instance: _DefaultInstance,
+    default_instance: DefaultInstance,
 ) -> Union[List[FieldDefinition], UnsupportedNestedTypeMessage]:
     # Handle general callables.
     if default_instance not in MISSING_SINGLETONS:
@@ -661,7 +692,7 @@ def _field_list_from_params(
             done = False
 
     # Sometime functools.* is applied to a class.
-    if isinstance(f, type):
+    if inspect.isclass(f):
         cls = f
         f = f.__init__  # type: ignore
 
@@ -701,16 +732,37 @@ def _field_list_from_params(
                 raise _instantiators.UnsupportedTypeAnnotationError(out.message)
             return out
 
+        # Set markers for positional + variadic arguments.
+        markers: Tuple[Any, ...] = ()
+        typ: Any = hints[param.name]
+        if param.kind is inspect.Parameter.POSITIONAL_ONLY:
+            markers = (_markers.Positional, _markers._PositionalCall)
+        elif param.kind is inspect.Parameter.VAR_POSITIONAL:
+            # Handle *args signatures.
+            #
+            # This will create a `--args T [T ...]` CLI argument.
+            markers = (_markers._UnpackArgsCall,)
+            typ = Tuple.__getitem__((typ, ...))  # type: ignore
+        elif param.kind is inspect.Parameter.VAR_KEYWORD:
+            # Handle *kwargs signatures.
+            #
+            # This will create a `--kwargs STR T [STR T ...]` CLI argument.
+            #
+            # Note that it would be straightforward to make both this and *args truly
+            # positional, omitting the --args/--kwargs prefix, but we are choosing not
+            # to because it would make *args and **kwargs difficult to use in
+            # conjunction.
+            markers = (_markers._UnpackKwargsCall,)
+            typ = Dict.__getitem__((str, typ))  # type: ignore
+
         field_list.append(
             FieldDefinition.make(
                 name=param.name,
                 # Note that param.annotation doesn't resolve forward references.
-                typ=hints[param.name],
+                typ=typ,
                 default=default,
                 helptext=helptext,
-                markers=(_markers.Positional, _markers._PositionalCall)
-                if param.kind is inspect.Parameter.POSITIONAL_ONLY
-                else (),
+                markers=markers,
             )
         )
 
