@@ -1,7 +1,8 @@
-from typing import Mapping, Type, TypeVar, Union
+from typing import Mapping, TypeVar, Union
 
 from typing_extensions import Annotated
 
+from .._typing import TypeForm
 from ..conf import subcommand
 
 T = TypeVar("T")
@@ -12,9 +13,35 @@ def subcommand_type_from_defaults(
     descriptions: Mapping[str, str] = {},
     *,
     prefix_names: bool = True,
-) -> Type[T]:
+) -> TypeForm[T]:
     """Construct a Union type for defining subcommands that choose between defaults.
 
+    .. warning::
+
+        Use of this helper is discouraged. It will likely be deprecated.
+
+        Using the the returned type is understood as an annotation by ``pyright`` and
+        ``pylance`` (with ``from __future__ import annotations``), but it relies on
+        behavior that isn't defined by the Python language specifications.
+
+        At the cost of verbosity, using :func:`tyro.conf.subcommand()` directly is
+        better supported by tools like ``mypy``.
+
+        Alternatively, we can work around this limitation with an ``if TYPE_CHECKING``
+        guard:
+
+        .. code-block:: python
+
+            from typing import TYPE_CHECKING
+
+            if TYPE_CHECKING:
+                # Static type seen by mypy, language servers, etc.
+                SelectableConfig = Config
+            else:
+                # Runtime type used by tyro.
+                SelectableConfig = subcommand_type_from_defaults(...)
+
+
     This can most commonly be used to create a "base configuration" pattern:
         https://brentyi.github.io/tyro/examples/10_base_configs/
 
@@ -62,16 +89,6 @@ def subcommand_type_from_defaults(
 
     tyro.cli(train)
     ```
-
-    Note that Pyright understands the latter case, but mypy does not. If mypy support is
-    necessary we can work around this with an `if TYPE_CHECKING` guard:
-
-    ```python
-    if TYPE_CHECKING:
-        SelectableConfig = Config
-    else:
-        SelectableConfig = subcommand_type_from_defaults(base_mapping)
-    ```
     """
     return Union.__getitem__(  # type: ignore
         tuple(
